summaryrefslogtreecommitdiff
path: root/src/mesa/drivers/windows/gdi/wmesadef.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/mesa/drivers/windows/gdi/wmesadef.h')
-rw-r--r--src/mesa/drivers/windows/gdi/wmesadef.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/mesa/drivers/windows/gdi/wmesadef.h b/src/mesa/drivers/windows/gdi/wmesadef.h
index 1c0e245111..a73609b007 100644
--- a/src/mesa/drivers/windows/gdi/wmesadef.h
+++ b/src/mesa/drivers/windows/gdi/wmesadef.h
@@ -7,10 +7,10 @@
/**
* The Windows Mesa rendering context, derived from GLcontext.
*/
struct wmesa_context {
- GLcontext gl_ctx; /* The core GL/Mesa context */
+ struct gl_context gl_ctx; /* The core GL/Mesa context */
HDC hDC;
COLORREF clearColorRef;
HPEN clearPen;
@@ -7,10 +7,10 @@
/**
- * The Windows Mesa rendering context, derived from GLcontext.
+ * The Windows Mesa rendering context, derived from struct gl_context.
*/
struct wmesa_context {